import { useForm } from 'antd/lib/form/Form'
import { useState } from 'react'
import { Button } from '../../elements/Button'
import { Form } from '../../elements/Form'
import { FormItem } from '../../elements/FormItem'
import { Input } from '../../elements/Input'
import { InputNumber } from '../../elements/InputNumber'
import { useStacks } from '../../hooks/getMany/useStacks'
import { Modal } from '../../layout/Modal'

import { Transaction } from '../../types'

type Props = {
  stackId: string
}

export const TransactionForm = ({ stackId }: Props) => {
  const [form] = useForm<Transaction>()
  const [visible, setVisible] = useState(true)
  const stacks = useStacks()

  const handleFinish = (tx: Transaction) => {
    console.log('creating tx ', tx)
  }

  const handleClose = () => {
    setVisible(false)
  }

  return (
    <Modal onCancel={handleClose} visible={visible}>
      <Form onFinish={handleFinish} form={form} className="form">
        <h3>Expense for {form.getFieldValue('stack')} account</h3>
        <FormItem label="Amount" name="amount">
          <InputNumber autoFocus />
        </FormItem>
        <FormItem label="Details" name="details">
          <Input />
        </FormItem>
        <FormItem name="Stack" label="Stack">
          <select>
            {stacks.data?.map((stack) => (
              <option value={stack.id}>{stack.name}</option>
            ))}
            <option value={-1} disabled>
              Select Account
            </option>
          </select>
        </FormItem>

        <Button htmlType="submit">Submit</Button>
      </Form>
    </Modal>
  )
}
