from django.contrib.auth.models import User, Group
from rest_framework import serializers
from server.api import models

class UserSerializer(serializers.ModelSerializer):
    class Meta:
        model = User
        fields = ['username', 'email', 'groups']

class TransactionSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Transaction
        fields = '__all__'

class StackSerializer(serializers.ModelSerializer):
    transactions = TransactionSerializer(many=True, read_only=True)

    class Meta:
        model = models.Stack
        fields = '__all__'

class AccountSerializer(serializers.ModelSerializer):
    stacks = serializers.PrimaryKeyRelatedField(many=True, read_only=True)
    users = serializers.SlugRelatedField(many=True, read_only=True, slug_field='username')

    class Meta:
        model = models.Account
        fields = '__all__'
