from django.contrib.auth.models import User, Group
from rest_framework import viewsets, permissions
from server.api import serializers, models

from datetime import datetime


class UserViewSet(viewsets.ModelViewSet):
    queryset = User.objects.all()
    serializer_class = serializers.UserSerializer
    permission_classes = [permissions.IsAuthenticated]

    def get_queryset(self):
        return [self.request.user]


class AccountViewSet(viewsets.ModelViewSet):
    queryset = models.Account.objects.all()
    serializer_class = serializers.AccountSerializer
    permission_classes = [permissions.IsAuthenticated]

    def get_queryset(self):
        return self.queryset.filter(users=self.request.user)


class StackViewSet(viewsets.ModelViewSet):
    queryset = models.Stack.objects.all()
    serializer_class = serializers.StackSerializer
    permission_classes = [permissions.IsAuthenticated]

    def get_queryset(self):
        return self.queryset.filter(account__users=self.request.user)


class TransactionViewSet(viewsets.ModelViewSet):
    queryset = models.Transaction.objects.all()
    serializer_class = serializers.TransactionSerializer
    permission_classes = [permissions.IsAuthenticated]

    def get_queryset(self):
        queryset = self.queryset.filter(stack__account__users=self.request.user)

        if self.action == 'list':
            month = self.request.query_params.get('month', '')
            stack = self.request.query_params.get('stack', '')

            if month:
                try:
                    dt = datetime.strptime(month, '%Y-%m')
                except ValueError:
                    raise exceptions.ValidationError(dict(month='Should be YYYY-MM.'))
                queryset = queryset.filter(created_at__year=dt.year)
                queryset = queryset.filter(created_at__month=dt.month)
            if stack:
                queryset = queryset.filter(stack=stack)

        return queryset.order_by('-created_at', '-id')
